@@ -56,7 +56,6 @@ class NumpyScalar:
         return paths
 
 
-Float128 = NumpyScalar("float128", "double[2]")
 Float64 = NumpyScalar("float64", "double")
 Float32 = NumpyScalar("float32", "float")
 Int64 = NumpyScalar("int64", "int64_t")
@@ -69,7 +68,8 @@ Int8 = NumpyScalar("int8", "int8_t")
 UInt8 = NumpyScalar("uint8", "uint8_t")
 Complex64 = NumpyScalar("complex64", "float[2]")
 Complex128 = NumpyScalar("complex128", "double[2]")
-Complex256 = NumpyScalar("complex256", "double[4]")
+#Complex256 = NumpyScalar("complex256", "double[4]")  # incompatible with M1 CPU
+#Float128 = NumpyScalar("float128", "double[2]")      # incompatible with M1 CPU
 
 
 def is_scalar(cls):
