@@ -22,11 +22,12 @@ Struct class:
 - _size: class size, None if not static
 - _fields: list of fields
 - _d_fields: list of dynamic fields
-- _s_fields: list of dynamic fields
+- _s_fields: list of static fields
 
 Struct instance:
 - _offsets: cached offsets of dynamic fields dict indexed by field.index
 - _sizes: cached sizes of dynamic fields dict indexed by field.index
+- _size: cached size of the object
 
 Field instance:
 - ftype
@@ -38,7 +39,6 @@ Field instance:
 - readonly
 
 
-
 """
 import logging
 from typing import Callable, Optional
@@ -279,6 +279,7 @@ class Struct(metaclass=MetaStruct):
             val = Int64._from_buffer(self._buffer, offset)
             _offsets[field.index] = val
         self._offsets = _offsets
+        self._size = self._get_size()
         self._post_init()
         return self
 
